@@ -8,12 +8,16 @@
   # Bioconductor package aroma.light
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
   # require("aroma.light") - install if missing
-  aroma.core:::.requireBiocPackage("aroma.light", neededBy=getName(pkg));
+  ns <- getNamespace("aroma.core");
+  .requireBiocPackage <- get(".requireBiocPackage", envir=ns)
+  .requireBiocPackage("aroma.light", neededBy=getName(pkg));
 } # .setupAromaCn()
 
 
 ############################################################################
 # HISTORY:
+# 2013-12-17
+# o Avoid using ':::'.
 # 2013-08-04
 # o Created from ditto for aroma.affymetrix.
 ############################################################################
