@@ -138,6 +138,8 @@ setMethodS3("callPeaks", "PeaksAndValleys", function(fit, expected=c(-1/2,-1/4,0
 
 
 setMethodS3("callPeaks", "data.frame", function(fit, ...) {
+  .Deprecated(msg="callPeaks() for data.frame:s is deprecated.  It will eventually be removed from the package.");
+
   # Argument 'fit';
   stopifnot(all(is.element(c("type", "x", "density"), colnames(fit))));
   class(fit) <- c("PeaksAndValleys", class(fit));
@@ -149,6 +151,8 @@ setMethodS3("callPeaks", "data.frame", function(fit, ...) {
 
 ##############################################################################
 # HISTORY
+# 2013-08-04 [HB]
+# o CLEANUP: Formally deprecated callPeaks() for data.frame.
 # 2012-09-18 [PN]
 # o BUG FIX: callPeaks() would return an error when used with flavor "all".
 # 2011-10-31 [HB]
