@@ -3,11 +3,6 @@ setConstructorS3("SnpData", function(data=NULL, ...) {
   extend(BasicObject(data), "SnpData");
 })
 
-
-setMethodS3("plot", "SnpData", function(x, ...) {
-  NextMethod("plot", x, ...);
-})
-
 setMethodS3("callGenotypes", "SnpData", function(this, ...) {
   obj <- asTotalFracBSnpData(this);
   res <- callGenotypes(obj, ...);
@@ -18,6 +13,8 @@ setMethodS3("callGenotypes", "SnpData", function(this, ...) {
 
 ############################################################################
 # HISTORY:
+# 2012-10-16
+# o CLEANUP: Dropped plot() for SnpData.
 # 2009-03-31
 # o Added pairedBoost() for CartesianSnpData.
 # 2009-03-30
